@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Reset User Preferences Plugin
-  * Copyright (c) 2008 Paul Lesniewski <paul@squirrelmail.org>,
+  * Copyright (c) 2008-2009 Paul Lesniewski <paul@squirrelmail.org>,
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -73,7 +73,7 @@ function reset_prefs_init()
   */
 function rp_sensitive_preference_names_do()
 {
-   return 'rp_backup_times, ';
+   return 'security_tokens, rp_backup_times, ';
 }
 
 
@@ -81,12 +81,19 @@ function rp_sensitive_preference_names_do()
 /**
   * Show note on main options page after button press
   *
+  * Runs on the "options_save" hook so we can change $max_refresh
+  * as well as on the "optpage_set_loadinfo" hook where we hook
+  * in a fake (do nothing) load mechanism - what we actually
+  * accomplish there is simply changing $optpage_name
+  *
+  * Nothing is done unless one of our buttons has been pressed
+  *
   */
 function reset_prefs_saved_options_do()
 {
 
    global $optpage, $optpage_loader, $optpage_file, $optpage_save_error,
-          $optpage_title, $optpage_name, $max_refresh;
+          $optpage_title, $optpage_name, $optpage_loadhook, $max_refresh;
 
    sq_change_text_domain('reset_prefs');
 
@@ -98,6 +105,7 @@ function reset_prefs_saved_options_do()
       //$optpage_title = _("Options - Personal Information");
       $optpage_title = _("Options");
       $max_refresh = SMOPT_REFRESH_ALL;
+      $optpage_loadhook = '';
    }
 
    else if ($optpage == 'rp_backup_user_prefs')
@@ -107,6 +115,7 @@ function reset_prefs_saved_options_do()
       $optpage_name = _("Preferences Backed Up");
       //$optpage_title = _("Options - Personal Information");
       $optpage_title = _("Options");
+      $optpage_loadhook = '';
    }
 
    else if ($optpage == 'rp_revert_user_prefs')
@@ -117,6 +126,7 @@ function reset_prefs_saved_options_do()
       //$optpage_title = _("Options - Personal Information");
       $optpage_title = _("Options");
       $max_refresh = SMOPT_REFRESH_ALL;
+      $optpage_loadhook = '';
    }
 
    else if ($optpage == 'rp_revert_user_prefs_none_selected')
@@ -126,6 +136,7 @@ function reset_prefs_saved_options_do()
       $optpage_save_error = array(_("Preferences not reverted - please select a backup set to revert to"));
       //$optpage_title = _("Options - Personal Information");
       $optpage_title = _("Options");
+      $optpage_loadhook = '';
    }
 
    sq_change_text_domain('squirrelmail');
@@ -165,7 +176,7 @@ function rp_reset_prefs_do()
    {
 
       rp_backup_and_replace_prefs();
-      header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_reset_user_prefs&optmode=submit');
+      header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_reset_user_prefs&optmode=submit&smtoken=' . sm_generate_security_token());
       exit;
 
    }
@@ -178,7 +189,7 @@ function rp_reset_prefs_do()
    {
 
       rp_backup_and_replace_prefs(array(), TRUE);
-      header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_backup_user_prefs&optmode=submit');
+      header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_backup_user_prefs&optmode=submit&smtoken=' . sm_generate_security_token());
       exit;
 
    }
@@ -192,7 +203,7 @@ function rp_reset_prefs_do()
 
       if (!sqGetGlobalVar('new_rp_backup_times', $new_rp_backup_times, SQ_FORM))
       {
-         header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_revert_user_prefs_none_selected&optmode=submit');
+         header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_revert_user_prefs_none_selected&optmode=submit&smtoken=' . sm_generate_security_token());
          exit;
       }
 
@@ -220,7 +231,7 @@ function rp_reset_prefs_do()
       // getPref() should force a reload of the preferences cache,
       // unless some third-party prefs backend works differently
       //
-      getPref($data_dir, $username . '-backup_' . $backup_time, 'show_num', 15);
+      getPref($data_dir, $username . '-backup_' . $backup_time, 'hililist', '');
       $replacement_prefs = $prefs_cache;
 
 
@@ -235,7 +246,7 @@ function rp_reset_prefs_do()
       // revert!
       //
       rp_backup_and_replace_prefs($replacement_prefs);
-      header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_revert_user_prefs&optmode=submit');
+      header('Location: ' . sqm_baseuri() . 'src/options.php?optpage=rp_revert_user_prefs&optmode=submit&smtoken=' . sm_generate_security_token());
       exit;
 
    }
@@ -281,7 +292,8 @@ function rp_backup_and_replace_prefs($replacement_prefs=array(),
    // any plugins adding to the list will not concatenate
    // their names onto the last one in your plugin's list.
    //
-   $no_override_pref_list = concat_hook_function('reset_user_prefs');
+   $null = NULL;
+   $no_override_pref_list = concat_hook_function('reset_user_prefs', $null);
    $preserved_prefs = array();
    if (!empty($no_override_pref_list))
    {
@@ -304,7 +316,7 @@ function rp_backup_and_replace_prefs($replacement_prefs=array(),
    // if needed, unless some third-party prefs backend works
    // differently
    //
-   getPref($data_dir, $username, 'show_num', 15);
+   getPref($data_dir, $username, 'hililist', '');
    $temp_prefs_cache = $prefs_cache;
    $prefs_cache = FALSE;
    $prefs_are_cached = FALSE;
@@ -594,7 +606,7 @@ function rp_save_backup_times($option)
          // getPref() should force a reload of the preferences cache,
          // unless some third-party prefs backend works differently
          //
-         getPref($data_dir, $username . '-backup_' . $backup_time, 'show_num', 15);
+         getPref($data_dir, $username . '-backup_' . $backup_time, 'hililist', '');
          $temp_prefs_cache = $prefs_cache;
 
 
